@@ -12,3 +12,10 @@ def _has_clean_wt(domain, add_before_check=True):
         repo.git.add("--all")
     is_clean = not repo.is_dirty()
     return is_clean
+
+def _active_branch(domain):
+    "Return the string name of the active branch of the repo."
+    repo = Repo(ns_path / domain)
+    active_branch = repo.active_branch.name
+    return active_branch
+
